[llvm-commits] CVS: llvm/include/llvm/CodeGen/ValueTypes.h

Dan Gohman djg at cray.com
Wed Jun 27 09:08:36 PDT 2007



Changes in directory llvm/include/llvm/CodeGen:

ValueTypes.h updated: 1.39 -> 1.40
---
Log message:

Rename ("shrinkify") MVT::isExtendedValueType to MVT::isExtendedVT.


---
Diffs of the changes:  (+6 -6)

 ValueTypes.h |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)


Index: llvm/include/llvm/CodeGen/ValueTypes.h
diff -u llvm/include/llvm/CodeGen/ValueTypes.h:1.39 llvm/include/llvm/CodeGen/ValueTypes.h:1.40
--- llvm/include/llvm/CodeGen/ValueTypes.h:1.39	Wed Jun 27 10:28:26 2007
+++ llvm/include/llvm/CodeGen/ValueTypes.h	Wed Jun 27 11:08:04 2007
@@ -95,9 +95,9 @@
   static const uint32_t SimpleTypeMask =
     (~uint32_t(0) << (32 - SimpleTypeBits)) >> (32 - SimpleTypeBits);
 
   /// MVT::isExtendedValueType - Test if the given ValueType is extended
   /// (as opposed to being simple).
-  static inline bool isExtendedValueType(ValueType VT) {
+  static inline bool isExtendedVT(ValueType VT) {
     return VT > SimpleTypeMask;
   }
 
@@ -117,7 +117,7 @@
   /// MVT::isVector - Return true if this is a vector value type.
   static inline bool isVector(ValueType VT) {
     return (VT >= FIRST_VECTOR_VALUETYPE && VT <= LAST_VECTOR_VALUETYPE) ||
-           isExtendedValueType(VT);
+           isExtendedVT(VT);
   }
   
   /// MVT::getVectorElementType - Given a vector type, return the type of
@@ -125,7 +125,7 @@
   static inline ValueType getVectorElementType(ValueType VT) {
     switch (VT) {
     default:
-      if (isExtendedValueType(VT))
+      if (isExtendedVT(VT))
         return VT & SimpleTypeMask;
       assert(0 && "Invalid vector type!");
     case v8i8 :
@@ -147,7 +147,7 @@
   static inline unsigned getVectorNumElements(ValueType VT) {
     switch (VT) {
     default:
-      if (isExtendedValueType(VT))
+      if (isExtendedVT(VT))
         return ((VT & ~SimpleTypeMask) >> SimpleTypeBits) - 1;
       assert(0 && "Invalid vector type!");
     case v16i8: return 16;
@@ -170,7 +170,7 @@
   static inline unsigned getSizeInBits(ValueType VT) {
     switch (VT) {
     default:
-      if (isExtendedValueType(VT))
+      if (isExtendedVT(VT))
         return getSizeInBits(getVectorElementType(VT)) *
                getVectorNumElements(VT);
       assert(0 && "ValueType has no known size!");
@@ -95,9 +95,9 @@
     (~uint32_t(0) << (32 - SimpleTypeBits)) >> (32 - SimpleTypeBits);
 
-  /// MVT::isExtendedValueType - Test if the given ValueType is extended
+  /// MVT::isExtendedVT - Test if the given ValueType is extended
   /// (as opposed to being simple).






More information about the llvm-commits mailing list